<?php
defined('C5_EXECUTE') or die(_("Access Denied."));
Loader::library('payment/controller', 'core_commerce');

class CoreCommerceJeroBankTransferPaymentMethodController extends CoreCommercePaymentController {

    private function defaultMessage() {
	$mess = "Thankyou for your purchase.

Your order number is [%ORDER%].

Please make payment as soon as possible into the following account, using your order number as the transaction reference:

Account name:   [%NAME%]
Bank branch:    [%BRANCH%]
Sort code:      [%CODE%]
Account number: [%NUMBER%]

Thanks again,
[%SITE%]";
	return $mess;
    }


    private function defaultText() {
	$mess = "Please make payment as soon as possible into the following account, using your order number as the transaction reference:

Account name:   <strong>[%NAME%]</strong>
Bank branch:    <strong>[%BRANCH%]</strong>
Sort code:      <strong>[%CODE%]</strong>
Account number: <strong>[%NUMBER%]</strong>";
	    return $mess;
    }

    public function method_form() {
	$pkg = Package::getByHandle('core_commerce');
	$this->set('PAYMENT_METHOD_JERO_BANK_TRANSFER_TRANSACTION_TYPE', $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_TRANSACTION_TYPE'));
	$this->set('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC', $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC'));
	$this->set('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC_NAME', $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC_NAME'));
	$this->set('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_BRANCH', $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_BRANCH'));
	$this->set('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_SORT', $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_SORT'));
	$this->set('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_RECEIPT', $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_RECEIPT'));

	$mess = $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_BODY');
	if (!$mess)
	    $mess=$this->defaultMessage();
	$this->set('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_BODY',$mess);
	$text = $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_FORM_TEXT');
	if (!$text)
	    $text=$this->defaultText();
	$this->set('PAYMENT_METHOD_JERO_BANK_TRANSFER_FORM_TEXT',$text);
    }

    public function validate() {
	$e = parent::validate();
	if ($this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC') == '') {
	    $e->add(t('Please enter your bank account number.'));
	}
	if ($this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_BRANCH') == '') {
	    $e->add(t('Please enter your bank branch.'));
	}
	return $e;
    }

    public function form() {
	$pkg = Package::getByHandle('core_commerce');
	$message = $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_FORM_TEXT');
	$message = preg_replace('@\[%BRANCH%\]@',$pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_BRANCH'),$message);
	$message = preg_replace('@\[%NAME%\]@',$pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC_NAME'),$message);
	$message = preg_replace('@\[%CODE%\]@',$pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_SORT'),$message);
	$message = preg_replace('@\[%NUMBER%\]@',$pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC'),$message);
	$this->set('PAYMENT_METHOD_JERO_BANK_TRANSFER_FORM_TEXT',t($message));
	$this->set('action', $this->action('submit'));
	return;
    }

    public function action_submit() {
	Loader::controller('/checkout');
	// This is necessary so that we can
	// call the various "on checkout complete" events
	$cnt = new CheckoutController();
	$cnt->testStep = false;
	$cnt->on_start();

	$ch = Loader::helper('/checkout/step', 'core_commerce');
	$steps = $ch->getSteps();

	Loader::model('order/current', 'core_commerce');
	$o = CoreCommerceCurrentOrder::get();
	$pkg = Package::getByHandle('core_commerce');
	if (strtolower($pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_TRANSACTION_TYPE')) == 'authorization') {
	    $o->setStatus(CoreCommerceOrder::STATUS_PENDING);
	} else {
	    $o->setStatus(CoreCommerceOrder::STATUS_AUTHORIZED);
	}

	if ($pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_RECEIPT') == 'true') {
	    $mh = Loader::helper('mail');
	    $mh->to($o->oEmail);
	    $mh->setSubject(SITE . " Payment Details");
	    $from = $pkg->config('EMAIL_RECEIPT_EMAIL');
	    $fromname = $pkg->config('EMAIL_RECEIPT_NAME');
	    if ($from) {
		if ($fromname)
		    $mh->from($from, $fromname);
		else
		    $mh->from($from, SITE);
	    }

	    $message = $pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_BODY');
	    $message = preg_replace('@\[%ORDER%\]@',$o->getInvoiceNumber(false),$message);
	    $message = preg_replace('@\[%BRANCH%\]@',$pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_BRANCH'),$message);
	    $message = preg_replace('@\[%NAME%\]@',$pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC_NAME'),$message);
	    $message = preg_replace('@\[%CODE%\]@',$pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_SORT'),$message);
	    $message = preg_replace('@\[%NUMBER%\]@',$pkg->config('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC'),$message);
	    $message = preg_replace('@\[%SITE%\]@',SITE,$message);

	    $mh->setBody(t($message));
	    try {
		$mh->sendMail();
	    } catch (Exception $e) {
		Log::addEntry('Error sending receipt email for order #' . $o->getOrderID() . ': ' . $e->getMessage());
	    }
	}

	Loader::model('payment/method','core_commerce');
	$method = CoreCommercePaymentMethod::getByHandle('jero_bank_transfer');
	parent::finishOrder($o, $method->paymentMethodName);
	$ch->setCurrentPagePath('/checkout/payment/form');
	$sch = $ch->getNextCheckoutStep();
	$this->redirect($sch->getRedirectURL());
    }

    public function save() {
	$pkg = Package::getByHandle('core_commerce');
	$pkg->saveConfig('PAYMENT_METHOD_JERO_BANK_TRANSFER_TRANSACTION_TYPE', $this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_TRANSACTION_TYPE'));
	$pkg->saveConfig('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_RECEIPT', $this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_RECEIPT'));

	$message = ($this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_BODY')) ? $this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_BODY') : $this->defaultMessage();
	$pkg->saveConfig('PAYMENT_METHOD_JERO_BANK_TRANSFER_EMAIL_BODY', $message);

	$text = ($this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_FORM_TEXT')) ? $this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_FORM_TEXT') : $this->defaultText();
	$pkg->saveConfig('PAYMENT_METHOD_JERO_BANK_TRANSFER_FORM_TEXT', $text);

	$pkg->saveConfig('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC', $this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC'));
	$pkg->saveConfig('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC_NAME', $this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_AC_NAME'));
	$pkg->saveConfig('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_SORT', $this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_SORT'));
	$pkg->saveConfig('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_BRANCH', $this->post('PAYMENT_METHOD_JERO_BANK_TRANSFER_BANK_BRANCH'));
    }
}